| Copyright | Ivan Lazar Miljenovic |
|---|---|
| License | MIT |
| Maintainer | Ivan.Miljenovic@gmail.com |
| Safe Haskell | Safe |
| Language | Haskell2010 |
Streaming.Conduit
Description
- fromStream :: Monad m => Stream (Of o) m r -> ConduitM i o m r
- fromStreamSource :: Monad m => Stream (Of a) m r -> Source m a
- fromStreamProducer :: Monad m => Stream (Of a) m r -> Producer m a
- asConduit :: Monad m => (Stream (Of i) m () -> Stream (Of o) m r) -> Conduit i m o
- toStream :: Monad m => Producer m o -> Stream (Of o) m ()
- asStream :: Monad m => Conduit i m o -> Stream (Of i) m () -> Stream (Of o) m ()
Converting from Streams
fromStream :: Monad m => Stream (Of o) m r -> ConduitM i o m r Source #
The result of this is slightly generic than a Source or a
Producer. If it fits in the types you want, you may wish to use
fromStreamProducer which is subject to fusion.
fromStreamSource :: Monad m => Stream (Of a) m r -> Source m a Source #
A type-specialised variant of fromStream that ignores the
result.
fromStreamProducer :: Monad m => Stream (Of a) m r -> Producer m a Source #
A more specialised variant of fromStream that is subject to
fusion.